Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/lis2mdl_simpletest.py
    :caption: examples/lis2mdl_simpletest.py
    :linenos:

.. literalinclude:: ../examples/lis2mdl_interrupt.py
    :caption: examples/lis2mdl_interrupt.py
    :linenos:

examples/lis2mdl_interrupt.py